@@ -1,4 +1,6 @@
-import login as login_acc
+import sys
+sys.path.append("..")
+from ..loginms import login as login_acc
 import aiohttp
 import datetime
 import requests
